@@ -8,7 +8,6 @@ create_pager_window (WnckScreen *screen,
 {
   GtkWidget *win;
   GtkWidget *pager;
-  GtkWidget *frame;
   
   win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
@@ -27,16 +26,13 @@ create_pager_window (WnckScreen *screen,
                     G_CALLBACK (gtk_main_quit),
                     NULL);
 
-  frame = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-  gtk_container_add (GTK_CONTAINER (win), frame);
-  
   pager = wnck_pager_new (screen);
 
   wnck_pager_set_orientation (WNCK_PAGER (pager), orientation);
   wnck_pager_set_n_rows (WNCK_PAGER (pager), 3);
+  wnck_pager_set_shadow_type (WNCK_PAGER (pager), GTK_SHADOW_IN);
   
-  gtk_container_add (GTK_CONTAINER (frame), pager);  
+  gtk_container_add (GTK_CONTAINER (win), pager);
   
   gtk_widget_show_all (win);
 }
